==> shogun-cpp-6.1.2-1.tar.bz2: Library/include/shogun/lib/config.h <==
#ifndef __SHOGUN_LIB_CONFIG_H__
#define __SHOGUN_LIB_CONFIG_H__

#define MACHINE "AMD64"

#define SFMT_MEXP 19937
#define DSFMT_MEXP 19937

/* #undef HAVE_HDF5 */
#define HAVE_CURL 1
/* #undef HAVE_JSON */
#define HAVE_XML 1
/* #undef HAVE_DOXYGEN */
/* #undef HAVE_LAPACK */
/* #undef HAVE_MVEC */
/* #undef HAVE_PROTOBUF */
/* #undef HAVE_TFLOGGER */

/* #undef HAVE_ARPACK */
/* #undef HAVE_VIENNACL */
/* #undef VIENNACL_VERSION */
/* #undef HAVE_OPENCV */
/* #undef HAVE_CATLAS */
/* #undef HAVE_ATLAS */
/* #undef HAVE_MKL */
/* #undef HAVE_NLOPT */
/* #undef USE_LPSOLVE */
/* #undef HAVE_PTHREAD */
#define HAVE_OPENMP 1
/* #undef USE_CPLEX */
/* #undef HAVE_COLPACK */
/* #undef HAVE_ARPREC */
/* #undef USE_META_INTEGRATION_TESTS */

/* #undef HAVE_POWL */
#define HAVE_LGAMMAL 1
/* #undef HAVE_SQRTL */
#define HAVE_LOG2 1
/* #undef USE_LOGCACHE */
/* #undef USE_LOGSUMARRAY */

/* Tells ViennaCL to use OpenCL as computation backend */
#define VIENNACL_WITH_OPENCL 1

/* Eigen Lapack optimization flags */
/* #undef EIGEN_USE_BLAS */
/* #undef EIGEN_USE_LAPACKE */
/* #undef EIGEN_USE_LAPACKE_STRICT */
/* #undef EIGEN_USE_MKL_VML */
/* #undef EIGEN_USE_MKL_ALL */

/* for linear algebra global backend setups */
/* #undef USE_EIGEN3_GLOBAL */
/* #undef USE_VIENNACL_GLOBAL */

/* #undef USE_EIGEN3_LINSLV */
/* #undef USE_VIENNACL_LINSLV */

/* #undef USE_EIGEN3_EIGSLV */
/* #undef USE_VIENNACL_EIGSLV */

/* Define to 1 if you have the declaration of `isfinite', and to 0 if you
   don't. */
/* #undef HAVE_DECL_ISFINITE */

/* Define to 1 if you have the declaration of `isinf', and to 0 if you don't. */
/* #undef HAVE_DECL_ISINF */

/* Define to 1 if you have the declaration of `isnan', and to 0 if you don't. */
/* #undef HAVE_DECL_ISNAN */

/* Define to 1 if you have the `finite' function. */
/* #undef HAVE_FINITE */

/* Define to 1 if you have the `fpclass' function. */
/* #undef HAVE_FPCLASS */

/* Define to 1 if you have the `isfinite' function. */
/* #undef HAVE_ISFINITE */

/* Define to 1 if you have the `isinf' function. */
/* #undef HAVE_ISINF */

/* Define to 1 if you have the `isnan' function. */
/* #undef HAVE_ISNAN */

/* Define to 1 if you have the `std::isfinite' function. */
/* #undef HAVE_STD_ISFINITE */

/* Define to 1 if you have the `std::isinf' function. */
/* #undef HAVE_STD_ISINF */

/* Define to 1 if you have the `std::isnan' function. */
/* #undef HAVE_STD_ISNAN */

/* #undef HAVE_DECL_SIGNGAM */

#define HAVE_FDOPEN 1

#define USE_SHORTREAL_KERNELCACHE 1
#define USE_BIGSTATES 1

/* #undef USE_HMMDEBUG */
#define USE_HMMCACHE 1
/* #undef USE_HMMPARALLEL */
/* #undef USE_HMMPARALLEL_STRUCTURES */

/* #undef USE_PATHDEBUG */

/* #undef USE_SVMLIGHT */
/* #undef USE_MOSEK */
#define USE_GPL_SHOGUN 1

#define USE_GLPK 1
#define USE_LZO 1
#define USE_GZIP 1
#define USE_BZIP2 1
/* #undef USE_LZMA */
#define USE_SNAPPY 1

#define HAVE_SSE2 1
#define HAVE_BUILTIN_VECTOR 1

/* #undef DARWIN */
/* #undef FREEBSD */
/* #undef LINUX */

/* #undef USE_SWIG_DIRECTORS */
/* #undef TRACE_MEMORY_ALLOCS */
/* #undef USE_JEMALLOC */

/* #undef HAVE_CXX0X */
#define HAVE_CXX11 1

/* does the compiler support abi::__cxa_demangle */
/* #undef HAVE_CXA_DEMANGLE */

/* random related defines */
/* #undef HAVE_ARC4RANDOM */
/* #undef DEV_RANDOM */

#endif /* __SHOGUN_LIB_CONFIG_H__ */

==> shogun-cpp-6.1.3-0.tar.bz2: Library/include/shogun/lib/config.h <==
#ifndef __SHOGUN_LIB_CONFIG_H__
#define __SHOGUN_LIB_CONFIG_H__

#define MACHINE "AMD64"

#define SFMT_MEXP 19937
#define DSFMT_MEXP 19937

/* #undef HAVE_HDF5 */
#define HAVE_CURL 1
/* #undef HAVE_JSON */
#define HAVE_XML 1
/* #undef HAVE_DOXYGEN */
/* #undef HAVE_LAPACK */
/* #undef HAVE_MVEC */
/* #undef HAVE_PROTOBUF */
/* #undef HAVE_TFLOGGER */

/* #undef HAVE_ARPACK */
/* #undef HAVE_VIENNACL */
/* #undef VIENNACL_VERSION */
/* #undef HAVE_OPENCV */
/* #undef HAVE_CATLAS */
/* #undef HAVE_ATLAS */
/* #undef HAVE_MKL */
/* #undef HAVE_NLOPT */
/* #undef USE_LPSOLVE */
/* #undef HAVE_PTHREAD */
#define HAVE_OPENMP 1
/* #undef USE_CPLEX */
/* #undef HAVE_COLPACK */
/* #undef HAVE_ARPREC */
/* #undef USE_META_INTEGRATION_TESTS */

#define HAVE_LGAMMAL 1
/* #undef USE_LOGCACHE */
/* #undef USE_LOGSUMARRAY */

/* Tells ViennaCL to use OpenCL as computation backend */
#define VIENNACL_WITH_OPENCL 1

/* Eigen Lapack optimization flags */
/* #undef EIGEN_USE_BLAS */
/* #undef EIGEN_USE_LAPACKE */
/* #undef EIGEN_USE_LAPACKE_STRICT */
/* #undef EIGEN_USE_MKL_VML */
/* #undef EIGEN_USE_MKL_ALL */

/* for linear algebra global backend setups */
/* #undef USE_EIGEN3_GLOBAL */
/* #undef USE_VIENNACL_GLOBAL */

/* #undef USE_EIGEN3_LINSLV */
/* #undef USE_VIENNACL_LINSLV */

/* #undef USE_EIGEN3_EIGSLV */
/* #undef USE_VIENNACL_EIGSLV */

/* #undef HAVE_DECL_SIGNGAM */

#define HAVE_FDOPEN 1

#define USE_SHORTREAL_KERNELCACHE 1
#define USE_BIGSTATES 1

/* #undef USE_HMMDEBUG */
#define USE_HMMCACHE 1
/* #undef USE_HMMPARALLEL */
/* #undef USE_HMMPARALLEL_STRUCTURES */

/* #undef USE_PATHDEBUG */

/* #undef USE_SVMLIGHT */
/* #undef USE_MOSEK */
#define USE_GPL_SHOGUN 1

#define USE_GLPK 1
#define USE_LZO 1
#define USE_GZIP 1
#define USE_BZIP2 1
/* #undef USE_LZMA */
#define USE_SNAPPY 1

#define HAVE_SSE2 1
#define HAVE_BUILTIN_VECTOR 1

/* #undef DARWIN */
/* #undef FREEBSD */
/* #undef LINUX */

#define USE_SWIG_DIRECTORS 1
/* #undef TRACE_MEMORY_ALLOCS */
/* #undef USE_JEMALLOC */

/* #undef HAVE_CXX0X */
#define HAVE_CXX11 1

/* does the compiler support abi::__cxa_demangle */
/* #undef HAVE_CXA_DEMANGLE */

/* random related defines */
/* #undef HAVE_ARC4RANDOM */
/* #undef DEV_RANDOM */

#endif /* __SHOGUN_LIB_CONFIG_H__ */
